//*****************************************************************************
//
// File Name	: 'Fram.h'
// Title		: Definitions FRAM implementation 
// Author		: Michael Meyer
// Created		: 12.08.2010
// Version		: 
// Target MCU	: AVR ATmega 644p
// Indicator	: FRAM
//
//
//*****************************************************************************

#ifndef _FRAM_H
#define _FRAM_H

 
//*****************************************************************************
// General definitions
// to store values for a specific day
typedef struct {
	uint32_t	LzZirkP;									// duration of Zirkulationspumpe activity
	uint32_t	LzVorlP;									// duration of Vorlaufpumpe activity
	uint32_t	LzWwP;										// duration of Ladepumpe activity
	uint32_t	LzBren;										// duration of Brenner activity 
	uint32_t	Dummy1;										// some dummy to keep the structure, if exended
	uint32_t	Dummy2;										// some dummy to keep the structure, if exended
	uint32_t	Dummy3;										// some dummy to keep the structure, if exended
	uint32_t	Dummy4;										// some dummy to keep the structure, if exended
	uint32_t	Dummy5;										// some dummy to keep the structure, if exended
	uint32_t	Dummy6;										// some dummy to keep the structure, if exended
} FramDayVal_s; 

// to store values linked to a specific time
typedef struct {
	TmrTime_s	When;										// when did it happen?
	uint32_t	Val;										// the assigned value
} FramTimeVal_s; 

typedef struct {											// to store min max values for temperatures
	FramTimeVal_s	Min;									// lowest temperature
	FramTimeVal_s	Max;									// highest temperature
	TmrTime_s		Since;									// since when
} FramMinMax_s; 


#define FM_SIZE		(0x2000l)								// the size of the buffer

// Positions of values in FRAM
//*****************************************
#define	FD_MAX				50								// max number of entries in this section
#define	FD_START_ADR		0								// start address in FRAM
#define	FD_ENTRY_SZ			sizeof(uint32_t)				// size of one entry

#define	FM_MAX_ABGAS		0								// to store the max Abgas temp during one day
// extend here for plain 32 bit values


//*****************************************
#define	FD_S_MAX			5								// max number of entries in this section
#define	FD_S_START_ADR		FD_START_ADR + (FD_MAX * FD_ENTRY_SZ)	// start address in FRAM
#define	FD_S_ENTRY_SZ		sizeof(FramMinMax_s)			// size of one entry

// extend here for storing min/max value with time

//*****************************************
#define	FD_D_MAX			5								// max number of entries in this section, 2 currently used
#define	FD_D_START_ADR		FD_S_START_ADR + (FD_S_MAX * FD_S_ENTRY_SZ)	// start address in FRAM
#define	FD_D_ENTRY_SZ		sizeof(FramDayVal_s)			// size of one entry

#define	FM_D_HEUTE			0
#define	FM_D_GESTERN		1
#define	FM_D_VGESTERN		2

//*****************************************************************************
// Function prototypes for FRAM

extern void 				FRAMInit(void);
extern void 				FRAMClear(void);
extern void					FRAMWriteLong(uint32_t Number, uint8_t Pos);
extern uint32_t				FRAMReadLong(uint8_t Pos);
extern void FRAMWriteBlock(uint8_t *Block, uint16_t StartAdr, uint16_t Size);
extern void FRAMReadBlock(uint8_t *Block, uint16_t StartAdr, uint16_t Size);

#endif
