//*****************************************************************************
//
// File Name	: 'HWConfig.h'
// Title		: Definitions related to Hardware IO
// Author		: Michael Meyer
// Created		: 15.10.2009
// Version		: 
// Target MCU	: AVR ATmega 128
//
//
//*****************************************************************************

#ifndef	_HWCONF_H
#define	_HWCONF_H

//*****************************************************************************
// IO-Definitions for main module

#ifndef XTAL
#define XTAL                        11059200                // the clock rate
#endif


// Summary of PortA					Direction	
// ==============================================
// 0:   FRAM_CS						output	
// 1:	WLAN_CS						output	
// 2:	WLANRES						output			
// 3:	unused						input	
// 4:	DEBUG						output	
// 5:	unused						input	
// 6:	unused						input	
// 7:	unused						input	

#define	PORTA_INIT			0xFF		// enable pull-ups, set to 1
#define	PORTA_DIR			0x17		// all inputs, but DEBUG and last 3 bits

#define	FRAM_CS				(1<<PA0)
#define	WLAN_CS				(1<<PA1)
#define	WLAN_RES			(1<<PA2)
#define	DBG_P				(1<<PA4)

#define FRAM_PORT			PORTA
#define FRAM_DIR			DDRA

#define WLANCS_PORT			PORTA
#define	WLANCS_DIR			DDRA

#define WLANRES_PORT		PORTA
#define WLANRES_DIR			DDRA

#define	DBG_PORT			PORTA

#define	DBG_PULSE			{DBG_PORT &= ~DBG_P; DBG_PORT |= DBG_P;}


// Summary of PortB					Direction	
// ==============================================
// 0:	unused						input	
// 1:	unused						input
// 2:	WLAN_ICHIP_RDY				input
// 3:	unused						input	
// 4:   SDCARD_CS					output
// 5:	SPI_MOSI					output	
// 6:	SPI_MISO					input	
// 7:	SPI_SCK						output	

#define	PORTB_INIT			0xFF		// enable pull-ups
#define	PORTB_DIR			0xB0		// all inputs by default

#define	SDCARD_PORT			PORTB
#define	SDCARD_DIR			DDRB

#define	WLANICHIP_PORT		PORTB
#define	WLANICHIP_DIR		DDRB
#define	WLANICHIP_PIN		PINB

#define	WLAN_ICHIP_RDY		(1<<PB2)
#define	SDCARD_CS			(1<<PB4)
#define	SPI_SCK				(1<<PB7)
#define	SPI_MOSI			(1<<PB5)
#define	SPI_MISO			(1<<PB6)


// Summary of Port C				Direction	
// ==============================================
// 0:	unused						input
// Rest is unused/JTAG Port

#define	PORTC_INIT		0x0F				// enable pull-ups, do not touch upper nibble used for JTAG
#define	PORTC_DIR		0x00				// all inputs


// Summary of PortD					Direction	
// ==============================================
// 0:	RXD0						input
// 1:	TXD0						output
// 2:	WLAN_SPI_RDY  (INT0)		input
// 3:	WLAN_DATA_RDY (INT1)		input
// 4:	unused						input
// 5:	LED1						output
// 6:	LED2						output
// 7:	LED3						output

#define	PORTD_INIT			0x1D	// enable pull-ups, pull-up for RXD0 is important!
#define	PORTD_DIR			0xE2	// all inputs


// WLAN Inputs
#define	WLANSTAT_PORT		PORTD
#define	WLANSTAT_DIR		DDRD
#define	WLANSTAT_PIN		PIND
#define	WLAN_DATA_RDY		(1<<PD3)

#define	WLAN_DATA_HEDGE		{ EICRA |= (1<<ISC11) | (1<<ISC10); } 
#define	WLAN_DATA_CLR_INT	{ EIFR |= (1<<INT1); }
#define	WLAN_EN_DATA_INT	{ EIMSK |= (1<<INT1); } 
#define	WLAN_DIS_DATA_INT	{ EIMSK &= ~(1<<INT1); }
#define	WLAN_DATA_SET		(WLANSTAT_PIN & WLAN_DATA_RDY)

#define	WLAN_SPIR_PORT		PORTD
#define	WLAN_SPIR_DIR		DDRD
#define	WLAN_SPIR_PIN		PIND
#define	WLAN_SPI_RDY		(1<<PD2)

#define	WLAN_SPIR_HEDGE		{ EICRA |= (1<<ISC01) | (1<<ISC00); }  
#define	WLAN_SPIR_CLR_INT	{ EIFR |= (1<<INT0); }
#define	WLAN_EN_SPIR_INT	{ WLAN_SPIR_CLR_INT; EIMSK |= (1<<INT0); }
#define	WLAN_DIS_SPIR_INT	{ EIMSK &= ~(1<<INT0); }
#define	WLAN_SPIR_SET		(WLAN_SPIR_PIN & WLAN_SPI_RDY)

#define	LED1				(1<<PD5)
#define	LED2				(1<<PD6)
#define	LED3				(1<<PD7)

#define	LED1_ON				{PORTD |= LED1;}
#define	LED1_OFF			{PORTD &= ~LED1;}
#define	LED1_TOGGLE			{PORTD ^= LED1;}

#define	LED2_ON				{PORTD |= LED2;}
#define	LED2_OFF			{PORTD &= ~LED2;}
#define	LED2_TOGGLE			{PORTD ^= LED2;}

#define	LED3_ON				{PORTD |= LED3;}
#define	LED3_OFF			{PORTD &= ~LED3;}
#define	LED3_TOGGLE			{PORTD ^= LED3;}

#endif
