//*****************************************************************************
//
// File Name	: 'Km271.h'
// Title		: Definitions related to prtocol handling of KM271 handling
// Author		: Michael Meyer
// Created		: 12.08.2010
// Version		: 
// Target MCU	: AVR ATmega 644p
// Indicator	: KM
//
//*****************************************************************************

#ifndef	_KM_H
#define	_KM_H

//*****************************************************************************
// Defines for the ControlTask

#define	KM_ISV_PRIO				tskIDLE_PRIORITY + 3		// higher priority for KM task

#define	KM_WAIT_SPI()			{xSemaphoreTake(qSPIMutex, portMAX_DELAY);}
#define	KM_RELEASE_SPI()		{xSemaphoreGive(qSPIMutex);}

#define	KM_DELAY_MS(x)			{vTaskDelay(x / portTICK_RATE_MS);}

// Parameter types
#define	KM_PAR_TEMP				0							// positive temperatur 1C 
#define	KM_PAR_TEMP_HALF		1							// positive temperatur 0.5C 
#define	KM_PAR_TEMP_NEG			2							// positive/negative temperatur 1C, values above 128 are neg
#define	KM_PAR_PERCENT			3							// percentage 1%
#define	KM_PAR_BITFIELD			4							// field of bits
#define	KM_PAR_MINUTES			5							// minutes
#define	KM_PAR_NUMBER			6							// generic number

// Some index values in heating data structure
#define	KM_I_HKBW1				0							// Heizkreis Betriebswerte 1
#define	KM_I_HKBW2				1							// Heizkreis Betriebswerte 2
#define	KM_I_TSV				2							// Vorlauf SOLL Temperatur
#define	KM_I_TIV				3							// Vorlauf IST Temperatur
#define	KM_I_TSR				4							// Raum SOLL Temperatur#
#define	KM_I_TIR				5							// Raum IST Temperatur
#define	KM_I_HPUMP				8							// Vorlaufpumpe
#define	KM_I_TIHKP10			10							// Heizkennlinie +10
#define	KM_I_TIHK0				11							// Heizkennlinie 0
#define	KM_I_TIHKM10			12							// Heizkennlinie -10
#define	KM_I_HWWBW1				13							// Warmwasser Betriebswerte 1
#define	KM_I_HWWBW2				14							// Warmwasser Betriebswerte 2
#define	KM_I_TSWW				15							// Warm Wasser SOLL Temperatur
#define	KM_I_TIWW				16							// Warm Wasser IST Temperatur
#define	KM_I_HWWLP				18							// Pumpen Warmwasser
#define	KM_I_TSKV				19							// Kessel Vorlauf SOLL Temperatur
#define	KM_I_TIKV				20							// Kessel Vorlauf IST Temperatur
#define	KM_I_TBRE				21							// Brenner Einschalt Temperatur
#define	KM_I_TBRA				22							// Brenner Ausschalt Temperatur
#define	KM_I_HKFEH				25							// Kessel Bit-Fehler
#define	KM_I_HKBET				26							// Kesselbetrieb
#define	KM_I_HBREN				27							// Brenneransteuerung
#define	KM_I_TIABG				28							// Abgas Temperatur
#define	KM_I_TIA				32							// Aussen IST Temperatur
#define	KM_I_TVA				33							// Aussen verzgert Temperatur


// Bit definitions

// For KM_I_HWWLP
#define	KM_HWWLP_LPUMP			(1<<0)						// Warmwasser Ladepumpe
#define	KM_HWWLP_CPUMP			(1<<1)						// Warmwasser Zirkulationspumpe


// For KM_I_HKBET
#define	KM_HKBET_TESTGAS		(1<<0)						// Abgastest

// For KM_I_HPUMP
#define	KM_HPUMP_VPUMP			(1<<5)						// Vorlaufpumpe (an ist 100 -> bit 5 gesetzt) 

// For KM_I_HBREN
#define	KM_HBREN_BRENNERON		(1<<0)						// Brenner an

// For KM_I_HKFEH
#define	KM_HKFEH_BRN			(1<<0)						// Brennerstrung
#define	KM_HKFEH_KSF			(1<<1)						// Kesselfhler
#define	KM_HKFEH_BRNC			(1<<3)						// Kessel bleibt kalt
#define	KM_HKFEH_GASF			(1<<4)						// Abgasfhler
#define	KM_HKFEH_GASL			(1<<5)						// Abgas ber Grenzwert

// For KM_I_HKBW1
#define	KM_HKBW1_AUT			(1<<2)						// Automatikbetrieb
#define	KM_HKBW1_WWPRIO			(1<<3)						// Vorrang Warmwasser
#define	KM_HKBW1_HOL			(1<<5)						// Ferienbetrieb

// For KM_I_HKBW2
#define	KM_HKBW2_SUMMER			(1<<0)						// Sommerbetrieb
#define	KM_HKBW2_DAY			(1<<1)						// Tagbetrieb
#define	KM_HKBW2_FB				(1<<2)						// Keine Kommunikation mit FB
#define	KM_HKBW2_VLF			(1<<3)						// Problem Vorlauffhler

// For KM_I_HWWBW1
#define	KM_HWWBW1_DIF			(1<<1)						// Desinfektion luft
#define	KM_HWWBW1_RLOADING		(1<<2)						// Nachladung
#define	KM_HWWBW1_EDIF			(1<<4)						// Fehler Desinfektion
#define	KM_HWWBW1_WWF			(1<<5)						// Fehler Warmwasserfhler
#define	KM_HWWBW1_WWC			(1<<6)						// Fehler Warmwasser bleibt kalt
#define	KM_HWWBW1_AND			(1<<7)						// Fehler Anode

// For KM_I_HWWBW2
#define	KM_HWWBW2_LOADING		(1<<0)						// Warmwasser Loading


//*****************************************************************************
// The structures

// This is the fixed part of the menu
// located in ROM
typedef struct {
	const uint8_t	Id;										// second byte of KM271 Event identifier
	const char 		*Name;									// textual name of the parameter (e.g. used for logging)
	const char 		*ATiName;								// parameter name for ATi command of LAN module
	const uint8_t	ParType;								// parameter type (see defines)
} KmParamR_s;

//*****************************************************************************
// Variables exported
extern xSemaphoreHandle 		qSPIMutex;						// the SPI Mutex controls acces to SPI bus
extern xTaskHandle 				xKmTaskHandle;
extern const 					KmParamR_s KmParamR[] PROGMEM;
extern uint8_t					KmParamD[];
#if	(INCLUDE_uxTaskGetStackHighWaterMark == 1)
uint16_t volatile				KmRxErr;					// count number of RX Errors
#endif

//*****************************************************************************
// Function prototypes for the temperature handling
extern uint8_t Km271TaskInit(void);
extern void KmUpdateAll(void);

#endif
